@@ -152,7 +152,7 @@ def parse_eff(eff, pos):
         aa_ref = eff.aa_ref if coding_pos else None
     if aa_ref == "":
         aa_ref = None
-    aa_pos = int(aa_pos_offset) + 1 if coding_pos else None
+    aa_pos = int(aa_pos_offset) + 1 if aa_pos_offset else None
 
     return [
         mut_type,
